@@ -3,7 +3,9 @@
 ## =================================
 
 seqxtract <- function(data, var, data.frame=FALSE) {
-	
+
+    ## tibble transformed into data frame
+    if (inherits(data, "tbl_df")) data <- as.data.frame(data) 	
 	## Extracting the sequences from the data set
 	if (missing(var) || is.null(var) || is.na(var[1]))
 		seqdata <- data
